fn find_bucket<'a>(
iter: SelectorIter<'a, SelectorImpl>,
quirks_mode: QuirksMode,
disjoint_buckets: &mut SmallVec<[Bucket<'a>; 5]>,
bucket_matches: &mut BucketMatches,
nested: bool,
) -> Bucket<'a>Expand description
Searches a compound selector from left to right, and returns the appropriate bucket for it.
It also populates disjoint_buckets with dependencies from nested selectors with any semantics like :is() and :where().
If the bucket is not guaranteed to cover the whole selector, it will set bucket_matches to either Unknown or Subject.