pub trait SelectorMapEntry: Sized + Clone {
// Required method
fn selector(&self) -> SelectorIter<'_, SelectorImpl>;
// Provided method
fn set_bucket_matches(&mut self, _: BucketMatches) { ... }
}Expand description
A trait to abstract over a given selector map entry.
Required Methods
Sourcefn selector(&self) -> SelectorIter<'_, SelectorImpl>
fn selector(&self) -> SelectorIter<'_, SelectorImpl>
Gets the selector we should use to index in the selector map.
Provided Methods
Sourcefn set_bucket_matches(&mut self, _: BucketMatches)
fn set_bucket_matches(&mut self, _: BucketMatches)
Notes the bucketing decision in the entry.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.